==> igniteui-react-charts-16.6.8.tgz: package/ES5/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var BollingerBandWidthIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(BollingerBandWidthIndicator, _super);
    function BollingerBandWidthIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandWidthIndicator.prototype.get_p5 = function () {
        return new BollingerBandWidthIndicatorStrategy();
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.get_qi = function () {
        return BollingerBandWidthIndicator.$;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qr", {
        get: function () {
            return typeGetValue(this.c(BollingerBandWidthIndicator.qu));
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.qu, a);
        },
        enumerable: true,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.qb = function () {
        return this.qr;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qq", {
        get: function () {
            return this.c(BollingerBandWidthIndicator.qt);
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.qt, a);
        },
        enumerable: true,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.p9 = function () {
        return this.qq;
    };
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.qu = StrategyBasedIndicator.qn(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.qt = StrategyBasedIndicator.qm(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
}(StrategyBasedIndicator));
export { BollingerBandWidthIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var BollingerBandWidthIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(BollingerBandWidthIndicator, _super);
    function BollingerBandWidthIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandWidthIndicator.prototype.get_qc = function () {
        return new BollingerBandWidthIndicatorStrategy();
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.get_qp = function () {
        return BollingerBandWidthIndicator.$;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qy", {
        get: function () {
            return typeGetValue(this.c(BollingerBandWidthIndicator.q1));
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.q1, a);
        },
        enumerable: true,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.qi = function () {
        return this.qy;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "qx", {
        get: function () {
            return this.c(BollingerBandWidthIndicator.q0);
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.q0, a);
        },
        enumerable: true,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.qg = function () {
        return this.qx;
    };
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.q1 = StrategyBasedIndicator.qu(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.q0 = StrategyBasedIndicator.qt(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
}(StrategyBasedIndicator));
export { BollingerBandWidthIndicator };
